summaryrefslogtreecommitdiff
path: root/tools/ci-build.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/ci-build.sh')
-rwxr-xr-xtools/ci-build.sh7
1 files changed, 5 insertions, 2 deletions
diff --git a/tools/ci-build.sh b/tools/ci-build.sh
index d0938ee2..88c0571b 100755
--- a/tools/ci-build.sh
+++ b/tools/ci-build.sh
@@ -239,9 +239,12 @@ case "$ci_buildsys" in
gnome-desktop-testing-runner -d /usr/local/share dbus/ || \
maybe_fail_tests
# these tests benefit from being re-run as root
sudo env LD_LIBRARY_PATH=/usr/local/lib \
- gnome-desktop-testing-runner -d /usr/local/share \
+ bash -c 'ulimit -S -n 1024; ulimit -H -n 4096; exec "$@"' bash \
+ gnome-desktop-testing-runner -d /usr/local/share \
+ dbus/test-dbus-daemon_with_config.test \
dbus/test-uid-permissions_with_config.test || \
maybe_fail_tests
fi
@@ -239,9 +239,12 @@ case "$ci_buildsys" in
gnome-desktop-testing-runner -d /usr/local/share dbus/ || \
maybe_fail_tests
- # these tests benefit from being re-run as root
+ # these tests benefit from being re-run as root, and one
+ # test needs a finite fd limit to be useful
sudo env LD_LIBRARY_PATH=/usr/local/lib \